@@ -2,6 +2,7 @@ import os
 import imp
 
 from etcaetera.adapter.base import Adapter
+from etcaetera.utils import format_key
 from etcaetera.constants import (
     JSON_EXTENSIONS,
     YAML_EXTENSIONS,
@@ -20,14 +21,14 @@ class File(Adapter):
 
         if file_extension.lower() in JSON_EXTENSIONS:
             import json
-            self.data = {self._format_key(k):v for k,v in json.load(fd).items()}
+            self.data = {format_key(k):v for k,v in json.load(fd).items()}
         elif file_extension.lower() in YAML_EXTENSIONS:
             from yaml import load as yload, dump as ydump
             try:
                 from yaml import CLoader as Loader
             except ImportError:
                 from yaml import Loader
-            self.data = {self._format_key(k):v for k,v in yload(fd, Loader=Loader).items()}
+            self.data = {format_key(k):v for k,v in yload(fd, Loader=Loader).items()}
         elif file_extension.lower() in PYTHON_EXTENSIONS:
             mod = imp.load_source('mod', self.filepath)
             self.data = {k:v for k,v in vars(mod).items() if k.isupper()}
