@@ -1,4 +1,4 @@
-from collections import deque
+from collections import deque, namedtuple
 
 from etcaetera.adapter import (
     Adapter,
@@ -11,6 +11,8 @@ from etcaetera.adapter import (
 
 class Config(dict):
     def __init__(self, defaults=None, overrides=None, *adapters):
+        self._subconfigs = {}
+
         self.adapters = AdapterSet(*adapters)
 
         if defaults is not None:
@@ -35,6 +37,17 @@ class Config(dict):
                     # Otherwise, append it
                     self.adapters.append(adapter)
 
+    def add_subconfig(self, name, subconfig):
+        """Attaches a sub-config to the current Config object"""
+        if not isinstance(subconfig, Config):
+            raise TypeError(
+                "Subconfig has to be of Config type. "
+                "Got {} instead".format(type(subconfig))
+            )
+
+        self._subconfigs[name] = subconfig
+        setattr(self, name, subconfig) 
+
     @property
     def defaults(self):
         return self.adapters.defaults
@@ -66,10 +79,12 @@ class Config(dict):
         self._adapters = AdapterSet(*value)
 
     def load(self):
+        # Adapters loading
         for adapter in self.adapters:
-            if isinstance(adapter, Env):
-                adapter.load(keys=self.keys())
-            else:
-                adapter.load()
-
+            adapter.load()
             self.update(adapter.data)
+
+        # Subconfigs loading
+        for subconfig in self._subconfigs.values():
+            subconfig.load()
+
